interface Frame {
    height: number;
    width: number;
}
export interface Canvas extends HTMLCanvasElement {
    centerX: number;
    centerY: number;
}
interface CacheCanvas {
    width: number;
    height: number;
    centerX: number;
    centerY: number;
}
interface CanvasEditorParams {
    scale: number;
    rotate: number;
    translate: {
        x: number;
        y: number;
    };
}
export declare class CanvasEditor {
    canvas: Canvas;
    ctx: CanvasRenderingContext2D | undefined | null;
    img: HTMLImageElement | undefined;
    scale: number;
    rotate: number;
    translate: {
        x: number;
        y: number;
    };
    constructor(canvasElem: Canvas, params: CanvasEditorParams);
    onScale(value: number): void;
    /** Source: https://math.stackexchange.com/a/2774481 */
    calculateScaleOnRotate(): number;
    getEditParams(): {
        translate: {
            x: number;
            y: number;
        };
        scale: number;
        rotate: number;
    };
    onRotate(value: number): void;
    onTranslate(deltaX: number, deltaY: number): void;
    setTransform(params: CanvasEditorParams): void;
    drawScene(options?: {
        withBackground: boolean;
    }): void;
    drawSceneAsAnimationFrame(): void;
    saveContext(): void;
    restoreContext(): void;
    initImage(src: string, frame: Frame): void;
    getImageParams(naturalWidth: number, naturalHeight: number): {
        dh: number;
        dw: number;
    };
    setImgCords(): void;
    setViewCoords(frame: Frame): void;
    initCanvas(): void;
    setCanvasSize(): void;
    resetCanvas(canvas: CacheCanvas): void;
    createMask(canvas: CacheCanvas): void;
    getEditedImageSrc(): {
        src: string;
        canvas: HTMLCanvasElement;
    };
    static getViewportSize(): {
        width: number;
        height: number;
    };
}
export {};
