/// <reference types="react" />
import { DragObjectWithType } from 'react-dnd';
import { Canvas, CanvasEditor } from './canvasEditor';
export interface EditorChildProps {
    backToOriginalImage?: () => void;
    backToPixImage?: () => void;
    editorImageSrc?: string;
    canvasEditor?: React.MutableRefObject<CanvasEditor | null>;
    handleRotate?: (delta: number) => void;
    rotate?: number;
    frame?: {
        height: number;
        width: number;
    };
    scale?: number;
    handleScaleChange?: (value: number) => void;
    isTranslateDisabled?: boolean;
    handleMoveStart?: (event: MouseEvent) => void;
    canvasRef?: React.MutableRefObject<Canvas | null>;
}
export interface ProcessImagesPayload {
    processImages: Job;
}
export interface AddTemplateImagePayload {
    addTemplateImage: Job;
}
export interface User {
    id?: number;
    email?: string;
    infos?: UserInfos;
    billingInfos?: UserInfos;
    statePlan?: SubscriptionPlanStateEnum;
    logo?: string;
    country?: string;
    city?: string;
    eu?: string;
    timezone?: string;
    signUpEmailSent?: boolean;
    useMirror?: boolean;
    useMirrorOcclusal?: boolean;
    customizationParameters?: UserCustomizationParameters;
    admin?: boolean;
    createdAt?: string;
    updatedAt?: string;
    planInfos?: PlanInfos;
}
export declare enum Gender {
    MALE = "MALE",
    FEMALE = "FEMALE"
}
export declare enum SubscriptionPlanStateEnum {
    NONE = "NONE",
    ONBOARDING = "ONBOARDING",
    TRIAL = "TRIAL",
    PAYMENT_PENDING = "PAYMENT_PENDING",
    ACTIVE = "ACTIVE",
    ACTIVE_WILL_EXPIRE = "ACTIVE_WILL_EXPIRE",
    ACTIVE_WILL_DOWNGRADE = "ACTIVE_WILL_DOWNGRADE"
}
export interface UserInfos {
    id?: number;
    firstName?: string;
    lastName?: string;
    gender?: Gender;
    softwareName?: string;
    hearAboutUs?: string;
    newsletter?: boolean;
    address?: string;
    zipcode?: string;
    city?: string;
    country?: string;
    phone?: string;
    company?: string;
}
export interface PlanInfos {
    invoices?: Invoice[];
    plan?: SubscriptionPlanEnum;
    plan2?: SubscriptionPlanProductEnum;
    numberOfPhotosUsed?: number;
    numberOfPhotosInPlan?: number;
    nextBilling?: string;
    card?: Card;
}
export interface Plan {
    plan: SubscriptionPlanProductEnum;
    price: number;
    numberOfPhotosInPlan: number;
}
export interface Invoice {
    date?: string;
    url?: string;
    amount?: number;
    currency?: string;
    paid?: boolean;
}
export declare enum SubscriptionPlanEnum {
    FREE = "FREE",
    SOLO_MONTHLY = "SOLO_MONTHLY",
    CABINET_MONTHLY = "CABINET_MONTHLY"
}
export declare enum SubscriptionPlanProductEnum {
    FREE = "FREE",
    BASIC = "BASIC",
    UNLIMITED = "UNLIMITED",
    NONE = "NONE"
}
export interface Card {
    brand?: string;
    exp_month?: number;
    exp_year?: number;
    last4?: string;
    country?: string;
    name?: string;
}
export interface UserInfosCreateInput {
    firstName: string;
    lastName: string;
    gender: Gender;
    softwareName: string;
    hearAboutUs: string;
    newsletter: boolean;
    address: string;
    zipcode: string;
    city: string;
    country: string;
    phone: string;
    company: string;
}
export interface UserBillingInfosCreateInput {
    address: string;
    zipcode: string;
    city: string;
    country: string;
}
export interface UserCustomizationParameters {
    id: string;
    useMirror: boolean;
    autoSoftwareFlip: boolean;
    useMirrorOcclusal: boolean;
    faceZoomLevel: FaceZoomLevel;
    faceBackgroundColor: string;
    occlusalCut: OcclusalCut;
    intraOralZoomLevel: IntraOralZoomLevel;
}
export declare enum FaceZoomLevel {
    LOW = "LOW",
    MEDIUM = "MEDIUM"
}
export declare enum OcclusalCut {
    SIX = "SIX",
    SEVEN = "SEVEN"
}
export declare enum IntraOralZoomLevel {
    LEVEL_85P = "LEVEL_85P",
    LEVEL_95P = "LEVEL_95P"
}
export interface Job {
    id: string;
    user: User;
    externalIdPatient: string;
    inputImages: Image[];
    processedImages: Image[];
    template: Image;
    progress: number;
    country?: string;
    city?: string;
    eu?: string;
    timezone?: string;
    totalSizeInputImagesMB?: number;
    uploadSpeedMBps?: number;
    uploadTimeS?: number;
    clientTypeFrom?: string;
    clientNameFrom?: string;
    sentToDataScienceAt?: string;
    timeDatascienceProcessS?: number;
    timeTotalProcessS?: number;
    createdAt: string;
    updatedAt: string;
    urlWebpageProgression: string;
    urlZip?: string;
}
export interface Image {
    id: string;
    idJob: string;
    idOriginalImage: string;
    filename: string;
    user: User;
    url: string;
    type: ImageTypeEnum;
    batchParameters: {
        [x: string]: any;
    };
    createdAt: string;
    updatedAt: string;
    editedUrl?: string;
}
export declare enum ImageTypeEnum {
    INTRA_ORALE_FRONTALE = "INTRA_ORALE_FRONTALE",
    INTRA_ORALE_GAUCHE = "INTRA_ORALE_GAUCHE",
    INTRA_ORALE_DROITE = "INTRA_ORALE_DROITE",
    OCCLUSALE_INFERIEURE = "OCCLUSALE_INFERIEURE",
    OCCLUSALE_SUPERIEURE = "OCCLUSALE_SUPERIEURE",
    VISAGE_FRONTAL_SANS_SOURIRE = "VISAGE_FRONTAL_SANS_SOURIRE",
    VISAGE_PROFIL_DROITE = "VISAGE_PROFIL_DROITE",
    VISAGE_FRONTAL_AVEC_SOURIRE = "VISAGE_FRONTAL_AVEC_SOURIRE",
    VISAGE_TROIS_QUARTS = "VISAGE_TROIS_QUARTS",
    AUTRE = "AUTRE",
    VISAGE_FRONTAL_DESSOUS = "VISAGE_FRONTAL_DESSOUS"
}
export interface PixPhotoProcessorStateProps {
    step: PhotoProcessorStep;
    editorState: EditorState;
    batch: ProcessedJob[];
}
export interface ProcessedJob {
    compositeState: CompositeState;
    jobState: JobState;
    jobId: string;
}
export interface PixPhotoProcessorActionPayload {
    setEditorState?: {
        state: boolean;
    };
    setPEProcessing?: {
        jobId: string;
    };
    setPEGallery?: {
        processedJob: Job;
    };
}
export declare enum PixPhotoProcessorActionType {
    CANCEL_EDIT_IMAGES = "CANCEL_EDIT_IMAGES",
    SAVE_EDIT_IMAGES = "SAVE_EDIT_IMAGES",
    SWITCH_EDIT_IMAGE = "SWITCH_EDIT_IMAGE",
    CHANGE_SOURCE = "CHANGE_SOURCE",
    SET_REDUCER = "SET_REDUCER",
    SET_EDITOR_STATE = "SET_EDITOR_ON",
    SET_STEP = "SET_STEP",
    SET_PE_PROCESSING = "SET_PE_PROCESSING",
    SET_PE_GALLERY = "SET_PE_GALLERY",
    SET_PE_COMPOSITE = "SET_PE_COMPOSITE",
    RESET_PHOTO_PROCESSOR = "RESET_PHOTO_PROCESSOR",
    SET_COMPOSITE_INITIALIZED = "SET_COMPOSITE_INITIALIZED",
    SET_COMPOSITE_IMAGE_LIST = "SET_COMPOSITE_IMAGE_LIST",
    SET_COMPOSITE_LOADING = "SET_COMPOSITE_LOADING",
    SELECT_COMPOSITE_IMAGE = "SELECT_COMPOSITE_IMAGE",
    UNSELECT_COMPOSITE_IMAGE = "UNSELECT_COMPOSITE_IMAGE",
    SET_COMPOSITE_LOGO_SOURCE = "SET_COMPOSITE_LOGO_SOURCE",
    REPLACE_COMPOSITE_IMAGE = "REPLACE_COMPOSITE_IMAGE",
    START_EDIT_IMAGE = "START_EDIT_IMAGE",
    CANCEL_EDIT_IMAGE = "CANCEL_EDIT_IMAGE",
    FINISH_EDIT_IMAGE = "FINISH_EDIT_IMAGE",
    SET_JOB_STATUT = "SET_JOB_STATUT",
    SET_JOB_PROGRESS = "SET_JOB_PROGRESS",
    SET_TEMPLATE_STATUS = "SET_TEMPLATE_STATUS",
    TRIGGER_DOWNLOAD = "TRIGGER_DOWNLOAD",
    RESET_DOWNLOAD_COUNTER = "RESET_DOWNLOAD_COUNTER",
    UPDATE_PROCESSED_IMAGE_URL = "UPDATE_PROCESSED_IMAGE_URL",
    UPDATE_TEMPLATE_ZIP_URL = "UPDATE_TEMPLATE_ZIP_URL",
    SWAP_JOB = "SWAP_JOB"
}
export interface PixPhotoProcessorAction {
    type: PixPhotoProcessorActionType;
    payload?: PixPhotoProcessorActionPayload;
}
export declare type _PixPhotoProcessorAction = {
    type: PixPhotoProcessorActionType.CANCEL_EDIT_IMAGES;
    batchIndex: number;
} | {
    type: PixPhotoProcessorActionType.SAVE_EDIT_IMAGES;
    batchIndex: number;
    currentEditSrc: string;
    currentEditParams: EditParams | undefined;
    currentId: string;
} | {
    type: PixPhotoProcessorActionType.SWITCH_EDIT_IMAGE;
    batchIndex: number;
    src: string;
    imageId: string;
    params: EditParams;
    editorSrc: string;
} | {
    type: PixPhotoProcessorActionType.CHANGE_SOURCE;
    batchIndex: number;
    imageId: string;
} | {
    type: PixPhotoProcessorActionType.SET_REDUCER;
    len: number;
} | {
    type: PixPhotoProcessorActionType.SET_EDITOR_STATE;
    state: boolean;
} | {
    type: PixPhotoProcessorActionType.SET_STEP;
    step: PhotoProcessorStep;
} | {
    type: PixPhotoProcessorActionType.SET_PE_PROCESSING;
    jobId: string;
    batchIndex: number;
} | {
    type: PixPhotoProcessorActionType.SET_PE_GALLERY;
    processedJob?: Job;
    batchIndex: number;
} | {
    type: PixPhotoProcessorActionType.SET_PE_COMPOSITE;
} | {
    type: PixPhotoProcessorActionType.RESET_PHOTO_PROCESSOR;
    batchIndex: number;
} | {
    type: PixPhotoProcessorActionType.SET_COMPOSITE_INITIALIZED;
    isInitialized: boolean;
    batchIndex: number;
} | {
    type: PixPhotoProcessorActionType.SET_COMPOSITE_IMAGE_LIST;
    imageList: CompositeImage[];
    batchIndex: number;
} | {
    type: PixPhotoProcessorActionType.SET_COMPOSITE_LOADING;
    isLoading: boolean;
    batchIndex: number;
} | {
    type: PixPhotoProcessorActionType.SELECT_COMPOSITE_IMAGE;
    payload: {
        imageId: string;
        position: Position;
        batchIndex: number;
    };
} | {
    type: PixPhotoProcessorActionType.UNSELECT_COMPOSITE_IMAGE;
    imageId: string;
    batchIndex: number;
} | {
    type: PixPhotoProcessorActionType.SET_COMPOSITE_LOGO_SOURCE;
    logoSrc: string;
    batchIndex: number;
} | {
    type: PixPhotoProcessorActionType.REPLACE_COMPOSITE_IMAGE;
    payload: {
        oldImageId: string;
        newImageId: string;
        batchIndex: number;
    };
} | {
    type: PixPhotoProcessorActionType.START_EDIT_IMAGE;
    imageId: string;
    batchIndex: number;
} | {
    type: PixPhotoProcessorActionType.FINISH_EDIT_IMAGE;
    payload: {
        imageId: string | undefined;
        src: string;
        params: EditParams;
        editorSrc: string;
        batchIndex: number;
    };
} | {
    type: PixPhotoProcessorActionType.CANCEL_EDIT_IMAGE;
    batchIndex: number;
} | {
    type: PixPhotoProcessorActionType.SET_JOB_STATUT;
    payload: {
        jobId: string;
        status: JOB_STATUTES;
        batchIndex: number;
    };
} | {
    type: PixPhotoProcessorActionType.SET_JOB_PROGRESS;
    progress: number;
    batchIndex: number;
} | {
    type: PixPhotoProcessorActionType.SET_TEMPLATE_STATUS;
    status: TEMPLATE_STATUTES;
    batchIndex: number;
} | {
    type: PixPhotoProcessorActionType.TRIGGER_DOWNLOAD;
    batchIndex: number;
} | {
    type: PixPhotoProcessorActionType.RESET_DOWNLOAD_COUNTER;
    batchIndex: number;
} | {
    type: PixPhotoProcessorActionType.UPDATE_PROCESSED_IMAGE_URL;
    payload: {
        imageId: string;
        editedUrl: string;
        batchIndex: number;
    };
} | {
    type: PixPhotoProcessorActionType.UPDATE_TEMPLATE_ZIP_URL;
    batchIndex: number;
    url?: string;
} | {
    type: PixPhotoProcessorActionType.SWAP_JOB;
    payload: {
        oldJobId: string;
        newJob: Job;
    };
};
export declare enum PhotoProcessorStep {
    WAITING_FOR_FILES = 0,
    PROCESSING = 1,
    GALLERY = 2,
    COMPOSITE = 3
}
export declare enum JOB_STATUTES {
    IDLE = "IDLE",
    PREPARING = "PREPARING",
    UPLOADING = "UPLOADING",
    PROCESSING = "PROCESSING",
    SUCCESS = "SUCCESS",
    FAILURE = "FAILURE"
}
export declare enum TEMPLATE_STATUTES {
    IDLE = "IDLE",
    UPLOADING = "UPLOADING",
    SUCCESS = "SUCCESS",
    FAILURE = "FAILURE"
}
export interface JobState {
    jobId?: string;
    job?: Job;
    jobProgress: number;
    jobStatus: JOB_STATUTES;
    error?: {
        [x: string]: string;
    };
    templateStatus: TEMPLATE_STATUTES;
    downloadCounter: number;
}
export interface EditorState {
    isOn: boolean;
}
export interface CompositeState {
    imageList: CompositeImage[];
    editingImage?: CompositeImage;
    logo: string;
    readOnly: boolean;
    isInitialized: boolean;
    isLoading?: boolean;
}
export interface EditParams {
    translate: {
        x: number;
        y: number;
    };
    scale: number;
    rotate: number;
}
export interface CompositeImage {
    id: string;
    type: ImageTypeEnum;
    status?: string;
    src: string;
    filename: string;
    editorSrc: string;
    processedSrc: string;
    originalSrc?: string;
    editParams?: EditParams;
    initEditParams?: EditParams;
    position: Position;
    aspectRatio?: number;
    naturalWidth: number;
    naturalHeight: number;
    isOriginal: boolean;
}
export interface TemplateImage {
    id: string;
    url: string;
    filename: string;
    originalUrl?: string;
    type: ImageTypeEnum;
}
export declare type Position = {
    [x: string]: number | null;
};
export declare enum IMAGE_TYPES {
    TOP_LEFT = "VISAGE_FRONTAL_SANS_SOURIRE",
    TOP_MIDDLE = "VISAGE_FRONTAL_AVEC_SOURIRE",
    TOP_RIGHT = "VISAGE_PROFIL_DROITE",
    MIDDLE_LEFT = "OCCLUSALE_SUPERIEURE",
    MIDDLE_RIGHT = "OCCLUSALE_INFERIEURE",
    BOTTOM_LEFT = "INTRA_ORALE_DROITE",
    BOTTOM_MIDDLE = "INTRA_ORALE_FRONTALE",
    BOTTOM_RIGHT = "INTRA_ORALE_GAUCHE"
}
export interface DragItem extends DragObjectWithType {
    image: CompositeImage;
}
